******************************************************************
* M. Wobisch - July 26, 2005           fn-interface.f
*
*   fastNLO user interface to PDF and alpha_s code
*   --> to be edited by user 
*       to interface own PDF/alphas code
*
* included:    
*      DOUBLE PRECISION FUNCTION FNALPHAS(MUR)
*      SUBROUTINE FNPDF(X,MUF,XPDF)
*
*  in the default version the PDF interface FNPDF is set up
*  to access LHAPDF - the alpha_s routine FNALPHAS calls
*  alphas-demo.f which is an iterative solution of the 2-loop RGE
*******************************************************************


      DOUBLE PRECISION FUNCTION FNALPHAS(MUR)
*-----------------------------------------------------------------
* MW 06/29/2005  - alphas interface to the fastNLO code
*
* alpha_s computation
*   input:   MUR     renormalization scale in GeV
*   output:  value of (alpha_s/2Pi) at scale MUR
*
*  !!!! again: this function must return  alpha_s/(2Pi)  !!!!!
*
*-----------------------------------------------------------------
      implicit real*8 (a-h,o-z)
      DOUBLE PRECISION MUR

      INCLUDE 'PDFCOM.'
      include 'CONSTCOM.'

!  Take the 5-flavour \alpha_s
      FNALPHAS=xqg(0,0.1d0,mur**2,2)/2./pi

      RETURN
      END

C *****************************************************************

      SUBROUTINE FNPDF(X,MUF,XPDF)
*-----------------------------------------------------------------
* MW 06/29/2005 
*
* PDF interface to the fastNLO usercode
*
*   input   X       parton momentum fraction 
*           MUF     factorization scale in GeV
*
*   output  XPDF(-6:6) array of PDF momentum densities i.e. x*pdf!
*                      using the LHAPDF numbering convention:
*        tbar, bbar, cbar, sbar, ubar, dbar, g, d, u, s, c, b, t
*         -6 ,  -5 ,  -4 ,  -3 ,  -2 ,  -1 , 0, 1, 2, 3, 4, 5, 6
*
*-----------------------------------------------------------------
      implicit real*8 (a-h,o-z)
      DOUBLE PRECISION X, MUF, XPDF(-6:6)

      INCLUDE 'PDFCOM.'

!  Take the 5-flavour PDFs

      xpdf(0)=xqg(1,x,muf**2,2)
      xpdf(1)=xqg(2,x,muf**2,2)
      xpdf(-1)=xqg(3,x,muf**2,2)
      xpdf(2)=xqg(4,x,muf**2,2)
      xpdf(-2)=xqg(5,x,muf**2,2)
      xpdf(3)=xqg(6,x,muf**2,2)
      xpdf(-3)=xqg(7,x,muf**2,2)
      xpdf(4)=xqg(8,x,muf**2,2)
      xpdf(-4)=xqg(9,x,muf**2,2)
      xpdf(5)=xqg(10,x,muf**2,2)
      xpdf(-5)=xqg(11,x,muf**2,2)
      xpdf(6)=0.
      xpdf(-6)=0.

      RETURN
      END
